@@ -149,15 +149,20 @@ setuptools.setup(
         if new:
             for i in new:
                 for x in i:
-                    setup = setup + x[0]+'='+x[1]
+                    setup = setup + ',\n' + x[0]+'='+x[1]
         setup = setup+')'
 
         self.createFile('./'+d+'/', 'setup.py', setup)
         self.createDir('./'+d+'/'+d)
         print('INFO[004] create the src dir')
-        self.createFile('./'+d+'/'+d, '__init__.py', '# your python file')
+        self.createFile('./'+d+'/'+d, '__init__.py', f'from .{n} import *')
         print('INFO[005] create the __init__.py file')
+        self.createFile('./'+d+'/'+d, f'{n}.py', '# your python file')
+        print(f'INFO[006] create the {n}.py file')
         print(f'{n} is success')
+        print('''Pleace use:
+              cd {n}
+              python setup.py sdist''')
 
     def createDir(self, dirName):
         name = dirName
@@ -172,6 +177,7 @@ setuptools.setup(
                     inp = input(
                         '文件已存在，是否删除？\nThe file already exists. Do you want to delete it? (y/N) ')
                     if inp == 'y':
+                        s
                         shutil.rmtree(name[2:])
                         break
                     elif inp == 'N':
@@ -182,33 +188,3 @@ setuptools.setup(
     def createFile(self, path, name, value):
         with open(path+name, 'w')as f:
             f.write(value)
-
-
-create((('index', '"i"'),),     path='./',
-       dirName='qtscompile/',
-       pkgName='qtscompile',
-       author='xiongtianshuo',
-       author_email='Mr_Xiongts@163.com',
-       description='.',
-       url='https://github.com/seoul2k/qtscompile',
-       project_urls={
-    "Bug Tracker": "https://github.com/seoul2k/qtscompile/issues",
-},
-    classifiers=[
-        'Development Status :: 4 - Beta',
-        'Operating System :: OS Independent',
-        'Intended Audience :: Developers',
-        'License :: OSI Approved :: BSD License',
-        'Programming Language :: Python',
-        'Programming Language :: Python :: Implementation',
-        'Programming Language :: Python :: 2',
-        'Programming Language :: Python :: 2.7',
-        'Programming Language :: Python :: 3',
-        'Programming Language :: Python :: 3.4',
-        'Programming Language :: Python :: 3.5',
-        'Programming Language :: Python :: 3.6',
-        'Programming Language :: Python :: 3.8',
-        'Topic :: Software Development :: Libraries'
-],
-    python_requires=2,
-    install_requires=[""])
